%*************************************************************************%
%                          U20 Friction Tool                              %
%                                                                         %
% This file is part of the U20 Friction Tool. The U20 Friction tool is    %
% free software. You can use, redistribute and modify it. If you publish  %
% results obtained with this tool (or any tool based on this code),       %
% please cite the following article:                                      %
%                                                                         %
% R.H.W. ten Thije, R. Akkerman, L. van der Meer, M. P. Ubbink,           %
% Tool-ply friction in thermoplastic composite forming,                   %
% International Journal of Material Forming, Volume 1, p. 953-956 (2008)  %
%                                                                         %
% This library is distributed in the hope that it will be useful, but     %
% WITHOUT ANY WARRANTY.                                                   %
%                                                                         %
% Copyright (C) 2009 Rene ten Thije.                                      %
% Developed at the University of Twente, the Netherlands.                 %
% Chair of Production Technology, www.pt.ctw.utwente.nl                   %
% info: r.tenthije@utwente.nl / r.akkerman@utwente.nl                     %
%                                                                         %
%*************************************************************************%

function [N,Ff] = giveNandFw(p,Contour,Material,Par)

% gives the bearing force N and the friction force Ff per unit width

dx = Contour.dx;
hc = Contour.y;
h0 = Par.h0;
v  = Par.v;
T  = Par.T;

% bearing force
N  = sum(p)*dx;

% friction force
h   = h0+hc; 
dpdx=centr_diff(p,dx);
gam_dot=v./h;  % shear rate
eta  =give_eta(Material,T,gam_dot); % eta

% with viscous traction after x0
tau = eta.*gam_dot;

% limits to tau
tau_critical = 1e3*Par.uplimit;   % critical shear stress at which wall slip occurs
tau(tau>tau_critical) = tau_critical;

Ff  = sum(h/2.*dpdx+tau)*dx;

% without!! viscous traction after x0
%Ff  = sum(h(p>0)/2.*dpdx(p>0))*dx+sum(eta(p>0).*gam_dot(p>0))*dx;